@@ -1,5 +1,6 @@
 library(lfe)
 options(lfe.threads=2,digits=5,warn=1)
+suppressWarnings(RNGversion("3.5.0"))
 set.seed(655320)
 x <- rnorm(5000,mean=200)
 x2 <- rnorm(length(x))
@@ -18,7 +19,7 @@ shirt.eff <- rnorm(nlevels(shirt))
 y <- x + 0.25*x2 + 0.5*x3 + id.eff[id] + firm.eff[firm] + shoe.eff[shoe] + shirt.eff[shirt] + rnorm(length(x))
 
 ## estimate
-summary(est <- felm(y ~ x+x2 + x3 |id+firm+shoe+shirt))
+print(est <- felm(y ~ x+x2 + x3 |id+firm+shoe+shirt))
 cat('Components:',nlevels(est$cfactor),'largest:',sum(est$cfactor == '1'),'\n')
 ## extract the group fixed effects
   ## verify that id and firm coefficients are 1
