@@ -1,5 +1,6 @@
 library(lfe)
 options(lfe.threads=2,digits=5,warn=1,lfe.eps=1e-5)
+suppressWarnings(RNGversion("3.5.0"))
 set.seed(42)
 x <- rnorm(400)
 x2 <- rnorm(length(x))
@@ -20,6 +21,7 @@ y <- x + 0.5*x2 + id.eff[id] + firm.eff[firm] + Q + R + u
 ## estimate and print result
 est <- felm(y ~ x+x2 | id+firm |(Q|R~x3+x4))
 summary(est,robust=TRUE)
+summary(felm(y ~ x+x2 | id+firm |(Q|R~x3+x4), kclass='liml'))
 update(est, . ~ x)
 # try it from within a function 
 fr <- data.frame(y,x,id,firm,Q,R,x3,x4)
