@@ -1,6 +1,7 @@
 library(lfe)
 options(lfe.threads=2,digits=3,warn=1)
 set.seed(655318)
+suppressWarnings(RNGversion("3.5.0"))
 x <- rnorm(500)
 x2 <- rnorm(length(x))
 
@@ -23,7 +24,7 @@ print(est <- felm(y ~ x+x2|id+firm, data=fr))
 ## extract the group fixed effects
 tail(getfe(est))
 
-head(model.matrix(est))
+head(round(model.matrix(est),7))
 head(model.matrix(est,centred=FALSE))
-head(model.matrix(felm(y ~ x+x2|id+firm, data=fr,keepCX=TRUE)))
+head(round(model.matrix(felm(y ~ x+x2|id+firm, data=fr,keepCX=TRUE)),7))
 head(model.matrix(felm(y ~ x+x2|id+firm, data=fr,keepX=TRUE), centred=FALSE))
