@@ -1,5 +1,6 @@
 library(lfe)
 options(lfe.threads=1,digits=4)
+suppressWarnings(RNGversion("3.5.0"))
 set.seed(42)
 N <- 1000
 K <- 40
@@ -18,6 +19,7 @@ summary(felm(y ~ x + id + firm, wei=w))
 # felm with projection says
 est <- felm(y ~x | id + firm, wei=w, keepX=TRUE)
 summary(est)
+head(sandwich::estfun(est))
 
 # test getfe:
 Kid <- nlevels(id)
